# ai.gpt 開発状況 (2025/01/06)

## 現在の状態

### ✅ 実装済み機能

1. **基本システム**
   - 階層的記憶システム（完全ログ→要約→コア→忘却）
   - 不可逆的な関係性システム（broken状態は修復不可）
   - AI運勢による日々の人格変動
   - 時間減衰による自然な関係性変化

2. **CLI機能**
   - `chat` - AIとの会話（Ollama/OpenAI対応）
   - `status` - 状態確認
   - `fortune` - AI運勢確認
   - `relationships` - 関係一覧
   - `transmit` - 送信チェック（現在はprint出力）
   - `maintenance` - 日次メンテナンス
   - `config` - 設定管理
   - `schedule` - スケジューラー管理
   - `server` - MCP Server起動

3. **データ管理**
   - 保存場所: `~/.config/aigpt/`
   - 設定: `config.json`
   - データ: `data/` ディレクトリ内の各種JSONファイル

4. **スケジューラー**
   - Cron形式とインターバル形式対応
   - 5種類のタスクタイプ実装済み
   - バックグラウンド実行可能

5. **MCP Server**
   - 9種類のツールを公開
   - Claude Desktopなどから利用可能

## 🚧 未実装・今後の課題

### 短期的課題

1. **自律送信の実装**
   - 現在: コンソールにprint出力
   - TODO: atproto (Bluesky) への実際の投稿機能
   - 参考: ai.bot (Rust/seahorse) との連携も検討

2. **テストの追加**
   - 単体テスト
   - 統合テスト
   - CI/CDパイプライン

3. **エラーハンドリングの改善**
   - より詳細なエラーメッセージ
   - リトライ機構

### 中期的課題

1. **ai.botとの連携**
   - Rust側のAPIエンドポイント作成
   - 送信機能の委譲

2. **より高度な記憶要約**
   - 現在: シンプルな要約
   - TODO: AIによる意味的な要約

3. **Webダッシュボード**
   - 関係性の可視化
   - 記憶の管理UI

### 長期的課題

1. **他のsyuiプロジェクトとの統合**
   - ai.card: カードゲームとの連携
   - ai.verse: メタバース内でのNPC人格
   - ai.os: システムレベルでの統合

2. **分散化**
   - atproto上でのデータ保存
   - ユーザーデータ主権の完全実現

## 次回開発時のエントリーポイント

### 1. 自律送信を実装する場合
```python
# src/ai_gpt/transmission.py を編集
# atproto-python ライブラリを追加
# _handle_transmission_check() メソッドを更新
```

### 2. ai.botと連携する場合
```python
# 新規ファイル: src/ai_gpt/bot_connector.py
# ai.botのAPIエンドポイントにHTTPリクエスト
```

### 3. テストを追加する場合
```bash
# tests/ディレクトリを作成
# pytest設定を追加
```

## 設計思想の要点（AI向け）

1. **唯一性（yui system）**: 各ユーザーとAIの関係は1:1で、改変不可能
2. **不可逆性**: 関係性の破壊は修復不可能（現実の人間関係と同じ）
3. **階層的記憶**: ただのログではなく、要約・コア判定・忘却のプロセス
4. **環境影響**: AI運勢による日々の人格変動（固定的でない）
5. **段階的実装**: まずCLI print → atproto投稿 → ai.bot連携

## 現在のコードベースの理解

- **言語**: Python (typer CLI, fastapi_mcp)
- **AI統合**: Ollama (ローカル) / OpenAI API
- **データ形式**: JSON（将来的にSQLite検討）
- **認証**: atproto DID（未実装だが設計済み）

このファイルを参照することで、次回の開発がスムーズに始められます。